@@ -39,7 +39,6 @@
 enum {
 	PROP_0,
 	PROP_SELECTED,
-	PROP_CURRENT_SET,
 	PROP_WINDOW
 };
 
@@ -103,7 +102,7 @@ on_app_preferences (GtkAction* action, SeahorseViewer* self)
 	g_return_if_fail (SEAHORSE_IS_VIEWER (self));
 	g_return_if_fail (GTK_IS_ACTION (action));
 
-	seahorse_preferences_show (seahorse_view_get_window (SEAHORSE_VIEW (self)), NULL);
+	seahorse_preferences_show (seahorse_viewer_get_window (self), NULL);
 }
 
 static void 
@@ -257,7 +256,7 @@ on_file_export_completed (GObject *source,
 	GError *error = NULL;
 
 	if (!seahorse_source_export_auto_finish (result, &error))
-		seahorse_util_handle_error (&error, seahorse_view_get_window (SEAHORSE_VIEW (self)),
+		seahorse_util_handle_error (&error, seahorse_viewer_get_window (self),
 		                            _("Couldn't export keys"));
 
 	g_object_unref (self);
@@ -280,7 +279,7 @@ on_key_export_file (GtkAction* action, SeahorseViewer* self)
 		return;
 
 	dialog = seahorse_util_chooser_save_new (_("Export public key"), 
-	                                         seahorse_view_get_window (SEAHORSE_VIEW (self)));
+	                                         seahorse_viewer_get_window (self));
 	seahorse_util_chooser_show_key_files (dialog);
 	seahorse_util_chooser_set_filename_full (dialog, objects);
 	uri = seahorse_util_chooser_save_prompt (dialog);
@@ -328,7 +327,7 @@ on_copy_export_complete (GObject *source,
 
 	output = seahorse_source_export_auto_finish (result, &error);
 	if (error != NULL) {
-		seahorse_util_handle_error (&error, seahorse_view_get_window (SEAHORSE_VIEW (self)),
+		seahorse_util_handle_error (&error, seahorse_viewer_get_window (self),
 		                            _("Couldn't retrieve data from key server"));
 		return;
 	}
@@ -423,7 +422,7 @@ on_key_delete (GtkAction* action, SeahorseViewer* self)
 		if (seahorse_object_get_usage (object) == SEAHORSE_USAGE_PRIVATE_KEY) {
 			gchar* prompt = g_strdup_printf (_("%s is a private key. Are you sure you want to proceed?"), 
 			                                 seahorse_object_get_label (object));
-			if (!seahorse_util_prompt_delete (prompt, GTK_WIDGET (seahorse_view_get_window (SEAHORSE_VIEW (self))))) {
+			if (!seahorse_util_prompt_delete (prompt, GTK_WIDGET (seahorse_viewer_get_window (self)))) {
 				g_free (prompt);
 				g_list_free (objects);
 				return;
@@ -761,9 +760,6 @@ seahorse_viewer_get_property (GObject *obj, guint prop_id, GValue *value,
 	case PROP_SELECTED:
 		g_value_set_object (value, seahorse_viewer_get_selected (self));
 		break;
-	case PROP_CURRENT_SET:
-		g_value_set_object (value, seahorse_viewer_get_current_set (self));
-		break;
 	case PROP_WINDOW:
 		g_value_set_object (value, seahorse_view_get_window (SEAHORSE_VIEW (self)));
 		break;
@@ -810,11 +806,7 @@ seahorse_viewer_class_init (SeahorseViewerClass *klass)
 	g_object_class_install_property (gobject_class, PROP_WINDOW,
 	           g_param_spec_object ("window", "Window", "Window of View",
 	                                GTK_TYPE_WIDGET, G_PARAM_READABLE));
-	
-	g_object_class_install_property (gobject_class, PROP_CURRENT_SET,
-	           g_param_spec_object ("current-set", "Current Set", "Currently visible set of objects",
-	                                SEAHORSE_TYPE_SET, G_PARAM_READABLE));
-	
+
 	exportable_predicate.flags = SEAHORSE_FLAG_EXPORTABLE;
 	deletable_predicate.flags = SEAHORSE_FLAG_DELETABLE;
 	importable_predicate.flags = SEAHORSE_FLAG_EXPORTABLE;
@@ -830,7 +822,6 @@ seahorse_viewer_implement_view (SeahorseViewIface *iface)
 	iface->get_selected = (gpointer)seahorse_viewer_get_selected;
 	iface->set_selected = (gpointer)seahorse_viewer_set_selected;
 	iface->get_selected_matching = (gpointer)seahorse_viewer_get_selected_matching;
-	iface->get_current_set = (gpointer)seahorse_viewer_get_current_set;
 	iface->get_window = (gpointer)seahorse_viewer_get_window;
 	iface->register_ui = (gpointer)seahorse_viewer_register_ui;
 	iface->register_commands = (gpointer)seahorse_viewer_register_commands;
@@ -958,15 +949,6 @@ seahorse_viewer_set_selected (SeahorseViewer* self, SeahorseObject* value)
 	SEAHORSE_VIEWER_GET_CLASS (self)->set_selected (self, value);
 }
 
-SeahorseSet*
-seahorse_viewer_get_current_set (SeahorseViewer* self)
-{
-	g_return_val_if_fail (SEAHORSE_IS_VIEWER (self), NULL);
-	g_return_val_if_fail (SEAHORSE_VIEWER_GET_CLASS (self)->get_current_set, NULL);
-	
-	return SEAHORSE_VIEWER_GET_CLASS (self)->get_current_set (self);
-}
-
 GtkWindow* 
 seahorse_viewer_get_window (SeahorseViewer* self) 
 {
